==> mx-datetime_21.11.tar.xz: mx-datetime-21.11/translations/mx-datetime_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>MXDateTime</name>
    <message>
        <location filename="datetime.ui" line="20"/>
        <location filename="datetime.cpp" line="596"/>
        <source>MX Date &amp; Time</source>
        <translation>MX Data &amp; Ora</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="26"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="40"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="73"/>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="100"/>
        <source>About...</source>
        <translation>Info...</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="124"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Data &amp; Ora</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="192"/>
        <source>H:mm:ss</source>
        <translation>O:mm:ss</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="278"/>
        <location filename="datetime.cpp" line="296"/>
        <location filename="datetime.cpp" line="303"/>
        <source>Hardware Clock</source>
        <translation>Orologio hardware</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="284"/>
        <source>Hardware Clock tools</source>
        <translation>Strumenti Orologio hardware</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="290"/>
        <source>Obtain information from the Hardware Clock and present it in the box below.</source>
        <translation>Ottieni informazioni dall&apos;Orologio hardware e presentale nella casella in basso.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="293"/>
        <source>Read the Hardware Clock</source>
        <translation>Leggi l&apos;Orologio hardware</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="300"/>
        <source>Apply systematic drift corrections to the Hardware Clock.</source>
        <translation>Applica correzioni sistematiche consecutive all&apos;orologio hardware.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="303"/>
        <source>Drift Adjust</source>
        <translation>Regolazione dello scarto</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="323"/>
        <source>Time transfer</source>
        <translation>Trasferimento del tempo</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="329"/>
        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
        <translation>Imposta immediatamente l&apos;Orologio di sistema in modo che corrisponda all&apos;ora corrente registrata dall&apos;Orologio hardware.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="332"/>
        <source>Hardware Clock to System Clock</source>
        <translation>Orologio hardware a Orologio di sistema</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="339"/>
        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
        <translation>Imposta immediatamente l&apos;Orologio hardware in modo che corrisponda all&apos;ora corrente registrata dall&apos;orologio di sistema.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="342"/>
        <source>System Clock to Hardware Clock</source>
        <translation>Orologio di sistema a Orologio hardware</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="349"/>
        <source>Update the drift factor for the Hardware Clock when it is being set.</source>
        <translation>Aggiorna il fattore di scarto per l&apos;orologio hardware quando viene impostato.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="352"/>
        <source>Update the drift</source>
        <translation>Aggiorna lo scarto</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="362"/>
        <source>Time zone for the Hardware Clock</source>
        <translation>Fuso orario per l&apos;Orologio hardware</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="368"/>
        <source>Local time</source>
        <translation>Ora locale</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="371"/>
        <source>Local</source>
        <translation>Locale</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="378"/>
        <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
        <translation>Tempo Coordinato Universalmente (o Tempo del Meridiano di Greenwich)</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="381"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="421"/>
        <source>Network Time</source>
        <translation>Tempo di rete</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="427"/>
        <source>Move the selected item down</source>
        <translation>Sposta l&apos;elemento selezionato verso il basso</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="438"/>
        <source>Move the selected item up</source>
        <translation>Sposta l&apos;elemento selezionato verso l&apos;alto</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="449"/>
        <source>Remove the current item from the list</source>
        <translation>Rimuovi l&apos;elemento corrente dall&apos;elenco</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="460"/>
        <source>Add an item to the list</source>
        <translation>Aggiungi un elemento all&apos;elenco</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="486"/>
        <source>Automatically update the System Clock with NTP servers:</source>
        <translation>Aggiorna automaticamente l&apos;Orologio di sistema con i server NTP:</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="493"/>
        <source>Immediately update the system clock with NTP servers.</source>
        <translation>Aggiorna immediatamente l&apos;Orologio di sistema con i server NTP.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="496"/>
        <source>Update Now</source>
        <translation>Aggiorna adesso</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="505"/>
        <source>List of NTP servers to use.</source>
        <translation>Elenco di server NTP da usare.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="521"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="526"/>
        <source>Address</source>
        <translation>Indirizzo</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="531"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="270"/>
        <source>Reading...</source>
        <translation>Leggo...</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="284"/>
        <source>Adjusting...</source>
        <translation>Sto regolando...</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="296"/>
        <location filename="datetime.cpp" line="303"/>
        <source>System Clock</source>
        <translation>Orologio di sistema</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="309"/>
        <source>The %1 time was transferred to the %2.</source>
        <translation>Il tempo %1 è stato trasferito al %2.</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="312"/>
        <source>The %1 time could not be transferred to the %2.</source>
        <translation>Il tempo %1 non può essere trasferito al %2.</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="350"/>
        <source>Updating...</source>
        <translation>Aggiorno...</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="360"/>
        <source>The system clock was updated successfully.</source>
        <translation>L&apos;orologio di sistema è stato aggiornato correttamente.</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="362"/>
        <source>The system clock could not be updated.</source>
        <translation>L&apos;orologio di sistema non può essere aggiornato.</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="364"/>
        <source>None of the NTP servers on the list are currently enabled.</source>
        <translation>Nessuno dei server NTP nell&apos;elenco è attualmente abilitato.</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="595"/>
        <source>About MX Date &amp; Time</source>
        <translation>Informazioni su MX Data &amp; Ora</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="596"/>
        <source>Version: </source>
        <translation>Versione: </translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="597"/>
        <source>GUI program for setting the time and date in MX Linux</source>
        <translation>Programma di interfaccia grafica per l&apos;impostazione di data e ora in MX Linux</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="599"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="600"/>
        <location filename="datetime.cpp" line="614"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="601"/>
        <source>Changelog</source>
        <translation>Registro delle modifiche</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="602"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="628"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="646"/>
        <source>MX Date &amp; Time Help</source>
        <translation>MX Data &amp; Ora Aiuto</translation>
    </message>
</context>
</TS>

==> mx-datetime_22.10.01.tar.xz: mx-datetime-22.8.01/translations/mx-datetime_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>MXDateTime</name>
    <message>
        <location filename="../datetime.ui" line="20"/>
        <location filename="../datetime.cpp" line="604"/>
        <source>MX Date &amp; Time</source>
        <translation>MX Data &amp; Ora</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="26"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="40"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="73"/>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="100"/>
        <source>About...</source>
        <translation>Info...</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="124"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Data &amp; Ora</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="192"/>
        <source>H:mm:ss</source>
        <translation>O:mm:ss</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="278"/>
        <location filename="../datetime.cpp" line="296"/>
        <location filename="../datetime.cpp" line="303"/>
        <source>Hardware Clock</source>
        <translation>Orologio hardware</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="284"/>
        <source>Hardware Clock tools</source>
        <translation>Strumenti Orologio hardware</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="290"/>
        <source>Obtain information from the Hardware Clock and present it in the box below.</source>
        <translation>Ottieni informazioni dall&apos;Orologio hardware e presentale nella casella in basso.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="293"/>
        <source>Read the Hardware Clock</source>
        <translation>Leggi l&apos;Orologio hardware</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="303"/>
        <source>Apply systematic drift corrections to the Hardware Clock.</source>
        <translation>Applica correzioni sistematiche consecutive all&apos;orologio hardware.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="306"/>
        <source>Drift Adjust</source>
        <translation>Regolazione dello scarto</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="329"/>
        <source>Time transfer</source>
        <translation>Trasferimento del tempo</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="335"/>
        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
        <translation>Imposta immediatamente l&apos;Orologio di sistema in modo che corrisponda all&apos;ora corrente registrata dall&apos;Orologio hardware.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="338"/>
        <source>Hardware Clock to System Clock</source>
        <translation>Orologio hardware a Orologio di sistema</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="348"/>
        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
        <translation>Imposta immediatamente l&apos;Orologio hardware in modo che corrisponda all&apos;ora corrente registrata dall&apos;orologio di sistema.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="351"/>
        <source>System Clock to Hardware Clock</source>
        <translation>Orologio di sistema a Orologio hardware</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="361"/>
        <source>Update the drift factor for the Hardware Clock when it is being set.</source>
        <translation>Aggiorna il fattore di scarto per l&apos;orologio hardware quando viene impostato.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="364"/>
        <source>Update the drift</source>
        <translation>Aggiorna lo scarto</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="374"/>
        <source>Time zone for the Hardware Clock</source>
        <translation>Fuso orario per l&apos;Orologio hardware</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="380"/>
        <source>Local time</source>
        <translation>Ora locale</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="383"/>
        <source>Local</source>
        <translation>Locale</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="390"/>
        <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
        <translation>Tempo Coordinato Universalmente (o Tempo del Meridiano di Greenwich)</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="393"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="433"/>
        <source>Network Time</source>
        <translation>Tempo di rete</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="439"/>
        <source>Move the selected item down</source>
        <translation>Sposta l&apos;elemento selezionato verso il basso</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="450"/>
        <source>Move the selected item up</source>
        <translation>Sposta l&apos;elemento selezionato verso l&apos;alto</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="461"/>
        <source>Remove the current item from the list</source>
        <translation>Rimuovi l&apos;elemento corrente dall&apos;elenco</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="472"/>
        <source>Add an item to the list</source>
        <translation>Aggiungi un elemento all&apos;elenco</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="498"/>
        <source>Automatically update the System Clock with NTP servers:</source>
        <translation>Aggiorna automaticamente l&apos;Orologio di sistema con i server NTP:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="505"/>
        <source>Immediately update the system clock with NTP servers.</source>
        <translation>Aggiorna immediatamente l&apos;Orologio di sistema con i server NTP.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="508"/>
        <source>Update Now</source>
        <translation>Aggiorna adesso</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="520"/>
        <source>List of NTP servers to use.</source>
        <translation>Elenco di server NTP da usare.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="536"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="541"/>
        <source>Address</source>
        <translation>Indirizzo</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="546"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="270"/>
        <source>Reading...</source>
        <translation>Leggo...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="284"/>
        <source>Adjusting...</source>
        <translation>Sto regolando...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="296"/>
        <location filename="../datetime.cpp" line="303"/>
        <source>System Clock</source>
        <translation>Orologio di sistema</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="309"/>
        <source>The %1 time was transferred to the %2.</source>
        <translation>Il tempo %1 è stato trasferito al %2.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="312"/>
        <source>The %1 time could not be transferred to the %2.</source>
        <translation>Il tempo %1 non può essere trasferito al %2.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="352"/>
        <source>Updating...</source>
        <translation>Aggiorno...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="365"/>
        <source>The system clock was updated successfully.</source>
        <translation>L&apos;orologio di sistema è stato aggiornato correttamente.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="367"/>
        <source>The system clock could not be updated.</source>
        <translation>L&apos;orologio di sistema non può essere aggiornato.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="369"/>
        <source>None of the NTP servers on the list are currently enabled.</source>
        <translation>Nessuno dei server NTP nell&apos;elenco è attualmente abilitato.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="603"/>
        <source>About MX Date &amp; Time</source>
        <translation>Informazioni su MX Data &amp; Ora</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="604"/>
        <source>Version: </source>
        <translation>Versione: </translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="605"/>
        <source>GUI program for setting the time and date in MX Linux</source>
        <translation>Programma di interfaccia grafica per l&apos;impostazione di data e ora in MX Linux</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="607"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="608"/>
        <location filename="../datetime.cpp" line="622"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="609"/>
        <source>Changelog</source>
        <translation>Registro delle modifiche</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="610"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="636"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="654"/>
        <source>MX Date &amp; Time Help</source>
        <translation>MX Data &amp; Ora Aiuto</translation>
    </message>
</context>
</TS>
